==> Myghty-0.98.tar.gz: Myghty-0.98/lib/myghty/cache.py <==
# $Id: cache.py,v 1.39 2005/05/09 20:58:27 zzzeek Exp $
# cache.py - cache API and implementation for Myghty
# Copyright (C) 2004, 2005 Michael Bayer mike_mp@zzzcomputing.com
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public License
# along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


from myghty.container import *
from myghty.util import *
import myghty.buffer
import re

class Cache:
    """a front-end to the containment API implementing a data cache.
    
    This is a per-request object and is not synchronized against other threads
    or processes.  (the containment API it talks to, is)."""
    
    CLASSES = {'dbm':DBMContainer, 'file':FileContainer, 'memory':MemoryContainer}

        
    def __init__(self, component, type = None, container_class = None , debug_file = None, **params):

        self.params = CacheArgs()
        self.params.set_params(**params)

        self.type = type    
        if component is not None:
            self.namespace = component.id
        else:
            self.namespace = None
        self.dict = {}

        # attach a ContainerContext to the component, which will hold
        # onto the namespacemanager(s) corresponding to that component.
        # the scope of the context is the same as that of the component,
        # so if a component is unused and gets garbage collected, its 
        # namespacemanagers will get collected as well.
        if component is not None:
            if hasattr(component, "_container_context"):
                self.context = component._container_context
            else:
                self.context = ContainerContext(log_file = debug_file)
                component._container_context = self.context
        
        
        if type is not None:
            self.container_class = Cache.CLASSES[type]
            
        elif container_class is None:
        
            if params.setdefault('data_dir', None) is not None:
                # DBMContainer is definitely faster than FileContainer
                # for caching
                self.container_class = DBMContainer
            else:
                self.container_class = MemoryContainer
                
        else:
            self.container_class = container_class



    
    def _get_container(self, key, **params):
        if not self.dict.has_key(key):
            self.dict[key] = self._create_container(self.namespace, key, **params)

        return self.dict[key]


    def _create_container(self, namespace, key, type = None, container_class = None, **params):
        if container_class is None:
            if type is not None:
                container_class = Cache.CLASSES[type]
            else:
                container_class = self.container_class

        cparams = self.params.get_params(**params)
        
        return container_class(context = self.context, namespace = namespace, key = key, **cparams)
    
        
    def set_container(self, key, **params):
        self.dict[key] = self._create_container(self.namespace, key, **params)
        return self.dict[key]

    def get_container(self, key, **params):
        return self._get_container(key, **params)
        
    def get_value(self, key, **params):
        return self._get_container(key, **params).get_value()

    def set_value(self, key, value, **params):
        self._get_container(key, **params).set_value(value)

    def remove_value(self, key):
        if self.dict.has_key(key):
            self.dict[key].clear_value()
            del self.dict[key]
            
    def clear(self):
        for key in self.dict.keys():
            self.dict[key].clear_value()

            self.dict = {}              
        
    # public dict interface
    def __getitem__(self, key): return self.get_value(key)
    
    def __contains__(self, key): 
        container = self._get_container(key)
        return container.has_current_value()

    def has_key(self, key): 
        container = self._get_container(key)
        return container.has_current_value()

        
    def __setitem__(self, key, value):self.set_value(key, value)


class CacheArgs(PrefixArgs):
    
    def __init__(self, **params):
        PrefixArgs.__init__(self, 'cache_')
        self.set_prefix_params(**params)
        
    def clone(self, **params):
        p = self.get_params(**params)
        arg = CacheArgs()
        arg.params = p
        return arg

    def get_cache(self, component, **params):
        return Cache(component, **self.get_params(**params))

==> Myghty-1.0.tar.gz: Myghty-1.0/lib/myghty/cache.py <==
# $Id: cache.py,v 1.1.1.1 2006/01/12 20:54:38 classic Exp $
# cache.py - cache API and implementation for Myghty
# Copyright (C) 2004, 2005 Michael Bayer mike_mp@zzzcomputing.com
#
# This module is part of Myghty and is released under
# the MIT License: http://www.opensource.org/licenses/mit-license.php
#
# 


from myghty.container import *
from myghty.util import *
import myghty.buffer
import re

class Cache:
    """a front-end to the containment API implementing a data cache.
    
    This is a per-request object and is not synchronized against other threads
    or processes.  (the containment API it talks to, is)."""
    

        
    def __init__(self, component, type = None, container_class = None , debug_file = None, **params):

        self.params = CacheArgs()
        self.params.set_params(**params)

        self.type = type    
        if component is not None:
            self.namespace = component.id
        else:
            self.namespace = None
        self.dict = {}

        # attach a ContainerContext to the component, which will hold
        # onto the namespacemanager(s) corresponding to that component.
        # the scope of the context is the same as that of the component,
        # so if a component is unused and gets garbage collected, its 
        # namespacemanagers will get collected as well.
        if component is not None:
            if hasattr(component, "_container_context"):
                self.context = component._container_context
            else:
                self.context = ContainerContext(log_file = debug_file)
                component._container_context = self.context
        
        
        if type is not None:
            self.container_class = container_registry(type, 'Container')
            
        elif container_class is None:
        
            if params.setdefault('data_dir', None) is not None:
                # DBMContainer is definitely faster than FileContainer
                # for caching
                self.container_class = DBMContainer
            else:
                self.container_class = MemoryContainer
                
        else:
            self.container_class = container_class



    
    def _get_container(self, key, **params):
        if not self.dict.has_key(key):
            self.dict[key] = self._create_container(self.namespace, key, **params)

        return self.dict[key]


    def _create_container(self, namespace, key, type = None, container_class = None, **params):
        if container_class is None:
            if type is not None:
                container_class = container_registry(type, 'Container')
            else:
                container_class = self.container_class

        cparams = self.params.get_params(**params)
        
        return container_class(context = self.context, namespace = namespace, key = key, **cparams)
    
        
    def set_container(self, key, **params):
        self.dict[key] = self._create_container(self.namespace, key, **params)
        return self.dict[key]

    def get_container(self, key, **params):
        return self._get_container(key, **params)
        
    def get_value(self, key, **params):
        return self._get_container(key, **params).get_value()

    def set_value(self, key, value, **params):
        self._get_container(key, **params).set_value(value)

    def remove_value(self, key):
        if self.dict.has_key(key):
            self.dict[key].clear_value()
            del self.dict[key]
            
    def clear(self):
        for key in self.dict.keys():
            self.dict[key].clear_value()

            self.dict = {}              
        
    # public dict interface
    def __getitem__(self, key):
        return self.get_value(key)
    
    def __contains__(self, key): 
        container = self._get_container(key)
        return container.has_current_value()

    def has_key(self, key): 
        container = self._get_container(key)
        return container.has_current_value()

       
    def __delitem__(self, key):
        self.remove_value(key)
 
    def __setitem__(self, key, value):
        self.set_value(key, value)


class CacheArgs(PrefixArgs):
    
    def __init__(self, **params):
        PrefixArgs.__init__(self, 'cache_')
        self.set_prefix_params(**params)
        
    def clone(self, **params):
        p = self.get_params(**params)
        arg = CacheArgs()
        arg.params = p
        return arg

    def get_cache(self, component, **params):
        return Cache(component, **self.get_params(**params))
